@@ -6,7 +6,6 @@ suppressMessages({
   library(ggplot2)
   library(ggbeeswarm)
   library(ggpmisc)
-  library(ggpubr)
   library(ggrepel)
   library(ggquickeda)
   library(Hmisc)
@@ -17,6 +16,7 @@ suppressMessages({
   library(shiny)
   library(shinyjs)
   library(survminer)
+  library(survival)
   library(table1)
   library(tidyr)
 })
